summaryrefslogtreecommitdiffstats
path: root/examples/dbus/dbus-chat/chat_adaptor.h
diff options
context:
space:
mode:
Diffstat (limited to 'examples/dbus/dbus-chat/chat_adaptor.h')
-rw-r--r--examples/dbus/dbus-chat/chat_adaptor.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/dbus/dbus-chat/chat_adaptor.h b/examples/dbus/dbus-chat/chat_adaptor.h
index e682665cce..2cb576724e 100644
--- a/examples/dbus/dbus-chat/chat_adaptor.h
+++ b/examples/dbus/dbus-chat/chat_adaptor.h
@@ -38,7 +38,7 @@
**
**
** This file was generated by qdbusxml2cpp version 0.7
** Command line was: qdbusxml2cpp -a chat_adaptor.h: com.trolltech.chat.xml
**
** qdbusxml2cpp is Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
**
@@ -64,14 +64,14 @@ class QVariant;
QT_END_NAMESPACE
/*
* Adaptor class for interface com.trolltech.chat
*/
class ChatAdaptor: public QDBusAbstractAdaptor
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.chat")
+ Q_CLASSINFO("D-Bus Interface", "org.example.chat")
Q_CLASSINFO("D-Bus Introspection", ""
-" <interface name=\"com.trolltech.chat\">\n"
+" <interface name=\"org.example.chat\">\n"
" <signal name=\"message\">\n"
" <arg direction=\"out\" type=\"s\" name=\"nickname\"/>\n"
" <arg direction=\"out\" type=\"s\" name=\"text\"/>\n"
@@ -38,7 +38,7 @@
**
** This file was generated by qdbusxml2cpp version 0.7
-** Command line was: qdbusxml2cpp -a chat_adaptor.h: com.trolltech.chat.xml
+** Command line was: qdbusxml2cpp -a chat_adaptor.h: org.example.chat.xml
**
** qdbusxml2cpp is Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
@@ -64,14 +64,14 @@ class QVariant;
QT_END_NAMESPACE
/*
- * Adaptor class for interface com.trolltech.chat
+ * Adaptor class for interface org.example.chat
*/
class ChatAdaptor: public QDBusAbstractAdaptor